@@ -11,9 +11,9 @@ use HTML::Entities qw(encode_entities);
 use Scalar::Util qw(looks_like_number blessed reftype refaddr);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-03-12'; # DATE
+our $DATE = '2024-03-16'; # DATE
 our $DIST = 'Data-Dump-HTML-Collapsible'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our @EXPORT = qw(dd);
 our @EXPORT_OK = qw(dump);
@@ -194,7 +194,8 @@ sub _dd_or_dump {
 
     my $res;
     if (@_ > 1) {
-        $res = "(" . join(",\n", map {_dump($_, '', 0)} @_) . ")";
+        die "Currently multiple arguments are not supported, plese only pass 1 argument";
+        #$res = "(" . join(",\n", map {_dump($_, '', 0)} @_) . ")";
     } else {
         $res = _dump($_[0], '', 0);
     }
@@ -229,7 +230,7 @@ Data::Dump::HTML::Collapsible - Dump Perl data structures as HTML document with
 
 =head1 VERSION
 
-This document describes version 0.004 of Data::Dump::HTML::Collapsible (from Perl distribution Data-Dump-HTML-Collapsible), released on 2024-03-12.
+This document describes version 0.005 of Data::Dump::HTML::Collapsible (from Perl distribution Data-Dump-HTML-Collapsible), released on 2024-03-16.
 
 =head1 SYNOPSIS
 
